@@ -17,9 +17,11 @@ class Consul(Registry):
         self.server_name = server_name
         (host, port) = host.split(":")
         self.c = consul.Consul(host, port)
+        print("consul addr {}".format(host))
 
     def register(self):
-        check = consul.Check.tcp(self.addr, self.port, self.register_interval, deregister=True)  # 健康检查的ip，端口，检查时间
+        check = consul.Check.tcp(host=self.addr, port=self.port, interval=self.register_interval,
+                                 deregister=self.register_interval + 5)  # 健康检查的ip，端口，检查时间
         self.c.agent.service.register(name=self.server_name, service_id=f"{self.server_name}-{self.addr}-{self.port}",
                                       address=self.addr, port=self.port, check=check)  # 注册服务部分
         print(f"注册服务{self.server_name}成功")
